@@ -22,5 +22,7 @@ use crate::filter::{filter_fn_one, Filter};
 ///     });
 /// ```
 pub fn remote() -> impl Filter<Extract = (Option<SocketAddr>,), Error = Infallible> + Copy {
-    filter_fn_one(|route| futures_util::future::ok(route.remote_addr()))
+    // TODO: should be replaced with just simple extensions insert by a
+    // make service and then gotten again here.
+    //filter_fn_one(|route| futures_util::future::ok(route.remote_addr()))
 }
